<?php
namespace Options;

use Interop\Container\ContainerInterface;
use Interop\Container\Exception\ContainerException;
use Zend\ServiceManager\Exception\ServiceNotCreatedException;
use Zend\ServiceManager\Exception\ServiceNotFoundException;
use Zend\ServiceManager\Factory\FactoryInterface;

/**
 * Class OptionsManagerFactory
 *
 * @package Options
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/strig/options
 */
final class OptionsManagerFactory implements FactoryInterface
{
    /**
     * Create an object
     *
     * @param  ContainerInterface $container
     * @param  string $requestedName
     * @param  null|array $options
     * @return object
     * @throws ServiceNotFoundException if unable to resolve the service.
     * @throws ServiceNotCreatedException if an exception is raised when
     *     creating a service.
     * @throws ContainerException if any other error occurs
     */
    public function __invoke(ContainerInterface $container, $requestedName, array $options = null)
    {
        $config = $container->get('config');
        $formManager = $container->get('FormElementManager');
        $table = $container->get($config['options']['table']);

        return new OptionsManager($config, $formManager, $table);
    }
}