<?php
namespace OptionsTest\ConfigAggregator;

use EpTest\ContainerAwareTrait;
use Options\ConfigAggregator\DatabaseProcessor;
use Options\Db\OptionsTableInterface;
use OptionsTest\Mock\MockOptionsProvider;
use PHPUnit\Framework\TestCase;

/**
 * Class DatabaseProcessorTest
 *
 * @package OptionsTest\ConfigAggregator
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/strig/options
 */
class DatabaseProcessorTest extends TestCase
{
    use ContainerAwareTrait;

    public function testProcessorWillQueryTheTable()
    {
        $container = $this->createContainer([
            'options' => [
                'table' => 'options',
                'providers' => [
                    MockOptionsProvider::class,
                ],
            ],

            'db' => [
                'tables' => [
                    'options' => [
                        'name' => 'options',
                    ],
                ],
            ],

            'dependencies' => [
                'factories' => [
                    'options' => function() {
                        $table = $this->createMock(OptionsTableInterface::class);
                        $table->expects($this->once())
                              ->method('getOptions')
                              ->willReturn([
                                  'options_1' => [
                                      'param_1' => 'override_1',
                                      'param_2' => 'override_2',
                                  ],

                                  'options_2' => [
                                      'param_1' => 'override_1',
                                      'param_2' => 'override_2',
                                  ],
                              ]);

                        return $table;
                    },
                ],
            ],
        ]);

        $config = $container->get('config');
        $processor = new DatabaseProcessor();

        $processed = $processor($config);

        $this->assertEquals('override_1', $processed['options_1']['param_1']);
        $this->assertEquals('override_2', $processed['options_1']['param_2']);
        $this->assertEquals('override_1', $processed['options_2']['param_1']);
        $this->assertEquals('override_2', $processed['options_1']['param_2']);
    }
}